@@ -17,11 +17,11 @@ B::RecDeparse - Deparse recursively into subroutines.
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 =head1 SYNOPSIS
 
@@ -190,6 +190,15 @@ sub pp_refgen {
  }
 }
 
+sub pp_srefgen {
+ my $self = shift;
+
+ return do {
+  local $self->{brd_sub} = 0;
+  $self->SUPER::pp_srefgen(@_);
+ }
+}
+
 sub pp_gv {
  my $self = shift;
 
@@ -248,6 +257,10 @@ C<pp_refgen>
 
 =item *
 
+C<pp_srefgen>
+
+=item *
+
 C<pp_gv>
 
 =back
@@ -285,7 +298,7 @@ Tests code coverage report is available at L<http://www.profvince.com/perl/cover
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008,2009,2010,2011,2013,2014 Vincent Pit, all rights reserved.
+Copyright 2008,2009,2010,2011,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
